# libpythonproVelton
Módulo para as aulas de construção de projeto com Pytools do curso Python Pro

[![Updates](https://pyup.io/repos/github/aurohm/libpythonproVelton/shield.svg)](https://pyup.io/repos/github/aurohm/libpythonproVelton/)
[![Python 3](https://pyup.io/repos/github/aurohm/libpythonproVelton/python-3-shield.svg)](https://pyup.io/repos/github/aurohm/libpythonproVelton/)


Para instalar:
````console
python3 -m venv .venv
source .venv\Scripts\activate
pip install - requirements-dev.tx
````
Para conferir a qualidade do código:
```console
flake8
```

Utilizado o GA para Integração Continua

Suportado a versão 3 de Python
